@@ -1,30 +1,17 @@
 /*
-    <one line to give the library's name and an idea of what it does.>
-    Copyright (C) 2012-2013  Vishesh Handa <me@vhanda.in>
+    SPDX-FileCopyrightText: 2012-2013 Vishesh Handa <me@vhanda.in>
 
     Adapted from KFileMetadataWidget
-    Copyright (C) 2008 by Sebastian Trueg <trueg@kde.org>
-    Copyright (C) 2009-2010 by Peter Penz <peter.penz@gmx.at>
+    SPDX-FileCopyrightText: 2008 Sebastian Trueg <trueg@kde.org>
+    SPDX-FileCopyrightText: 2009-2010 Peter Penz <peter.penz@gmx.at>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+    SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
 #include "filemetadatawidget.h"
+#include "filemetadataprovider.h"
 #include "metadatafilter.h"
 #include "widgetfactory.h"
-#include "filemetadataprovider.h"
 
 #include <KConfig>
 #include <KConfigGroup>
@@ -32,58 +19,57 @@
 #include <KFileMetaData/UserMetaData>
 
 #include <QCheckBox>
+#include <QDebug>
+#include <QFileInfo>
 #include <QGridLayout>
 #include <QLabel>
-#include <QSpacerItem>
 #include <QList>
 #include <QSet>
+#include <QSpacerItem>
 #include <QString>
 #include <QTimer>
-#include <QFileInfo>
-#include <QDebug>
 
 using namespace Baloo;
 
-class Baloo::FileMetaDataWidget::Private
+class Baloo::FileMetaDataWidgetPrivate
 {
 public:
-    struct Row
-    {
-        QCheckBox* checkBox;
-        QLabel* label;
-        QWidget* value;
+    struct Row {
+        QCheckBox *checkBox;
+        QLabel *label;
+        QWidget *value;
     };
 
-    Private(FileMetaDataWidget* parent);
-    ~Private();
+    FileMetaDataWidgetPrivate(FileMetaDataWidget *parent);
+    ~FileMetaDataWidgetPrivate();
 
     void deleteRows();
 
     void slotLoadingFinished();
-    void slotLinkActivated(const QString& link);
+    void slotLinkActivated(const QString &link);
     void slotDataChangeStarted();
     void slotDataChangeFinished();
 
-    QStringList sortedKeys(const QVariantMap& data) const;
-    QLabel* createLabel(const QString &key,  const QString& itemLabel, FileMetaDataWidget* parent);
+    QStringList sortedKeys(const QVariantMap &data) const;
+    QLabel *createLabel(const QString &key, const QString &itemLabel, FileMetaDataWidget *parent);
 
     void saveConfig();
 
     QList<Row> m_rows;
-    FileMetaDataProvider* m_provider;
-    QGridLayout* m_gridLayout;
+    FileMetaDataProvider *m_provider;
+    QGridLayout *m_gridLayout;
 
-    MetadataFilter* m_filter;
-    WidgetFactory* m_widgetFactory;
+    MetadataFilter *m_filter;
+    WidgetFactory *m_widgetFactory;
 
     QMap<QString, bool> m_visibilityChanged;
     bool m_configureVisibleProperties = false;
 
 private:
-    FileMetaDataWidget* const q;
+    FileMetaDataWidget *const q;
 };
 
-FileMetaDataWidget::Private::Private(FileMetaDataWidget* parent)
+FileMetaDataWidgetPrivate::FileMetaDataWidgetPrivate(FileMetaDataWidget *parent)
     : m_rows()
     , m_provider(nullptr)
     , m_gridLayout(nullptr)
@@ -92,21 +78,21 @@ FileMetaDataWidget::Private::Private(FileMetaDataWidget* parent)
     m_filter = new MetadataFilter(q);
 
     m_widgetFactory = new WidgetFactory(q);
-    connect(m_widgetFactory, &WidgetFactory::urlActivated, q, &FileMetaDataWidget::urlActivated);
+    QObject::connect(m_widgetFactory, &WidgetFactory::urlActivated, q, &FileMetaDataWidget::urlActivated);
 
     // TODO: If KFileMetaDataProvider might get a public class in future KDE releases,
     // the following code should be moved into KFileMetaDataWidget::setModel():
     m_provider = new FileMetaDataProvider(q);
-    connect(m_provider, &FileMetaDataProvider::loadingFinished, q, [this](){ slotLoadingFinished(); });
+    QObject::connect(m_provider, &FileMetaDataProvider::loadingFinished, q, [this]() {
+        slotLoadingFinished();
+    });
 }
 
-FileMetaDataWidget::Private::~Private()
-{
-}
+FileMetaDataWidgetPrivate::~FileMetaDataWidgetPrivate() = default;
 
-void FileMetaDataWidget::Private::deleteRows()
+void FileMetaDataWidgetPrivate::deleteRows()
 {
-    for (const Row& row : qAsConst(m_rows)) {
+    for (const Row &row : qAsConst(m_rows)) {
         delete row.label;
         row.value->deleteLater();
         if (row.checkBox) {
@@ -117,9 +103,9 @@ void FileMetaDataWidget::Private::deleteRows()
     m_rows.clear();
 }
 
-QLabel* FileMetaDataWidget::Private::createLabel(const QString &key, const QString& itemLabel, FileMetaDataWidget* parent)
+QLabel *FileMetaDataWidgetPrivate::createLabel(const QString &key, const QString &itemLabel, FileMetaDataWidget *parent)
 {
-    QLabel* label = new QLabel(itemLabel + QLatin1Char(':'), parent);
+    QLabel *label = new QLabel(itemLabel + QLatin1Char(':'), parent);
     label->setTextInteractionFlags(Qt::TextSelectableByMouse | Qt::TextSelectableByKeyboard);
     label->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Preferred);
     label->setForegroundRole(parent->foregroundRole());
@@ -130,7 +116,7 @@ QLabel* FileMetaDataWidget::Private::createLabel(const QString &key, const QStri
     return label;
 }
 
-void FileMetaDataWidget::Private::slotLoadingFinished()
+void FileMetaDataWidgetPrivate::slotLoadingFinished()
 {
     deleteRows();
 
@@ -175,7 +161,7 @@ void FileMetaDataWidget::Private::slotLoadingFinished()
 
     const int labelColumn = m_configureVisibleProperties ? 1 : 0;
 
-    for (const auto& key : keys) {
+    for (const auto &key : keys) {
         Row row;
         if (m_configureVisibleProperties) {
             row.checkBox = new QCheckBox(q);
@@ -183,8 +169,9 @@ void FileMetaDataWidget::Private::slotLoadingFinished()
                 row.checkBox->setChecked(true);
             }
             m_gridLayout->addWidget(row.checkBox, rowIndex, 0, Qt::AlignTop | Qt::AlignRight);
-            connect(row.checkBox, &QCheckBox::stateChanged,
-                    q, [this, key](int state) { this->m_visibilityChanged[key] = (state == Qt::Checked); });
+            QObject::connect(row.checkBox, &QCheckBox::stateChanged, q, [this, key](int state) {
+                this->m_visibilityChanged[key] = (state == Qt::Checked);
+            });
         } else {
             row.checkBox = nullptr;
         }
@@ -214,7 +201,7 @@ void FileMetaDataWidget::Private::slotLoadingFinished()
     Q_EMIT q->metaDataRequestFinished(m_provider->items());
 }
 
-void FileMetaDataWidget::Private::slotLinkActivated(const QString& link)
+void FileMetaDataWidgetPrivate::slotLinkActivated(const QString &link)
 {
     const QUrl url = QUrl::fromUserInput(link);
     if (url.isValid()) {
@@ -222,17 +209,17 @@ void FileMetaDataWidget::Private::slotLinkActivated(const QString& link)
     }
 }
 
-void FileMetaDataWidget::Private::slotDataChangeStarted()
+void FileMetaDataWidgetPrivate::slotDataChangeStarted()
 {
     q->setEnabled(false);
 }
 
-void FileMetaDataWidget::Private::slotDataChangeFinished()
+void FileMetaDataWidgetPrivate::slotDataChangeFinished()
 {
     q->setEnabled(true);
 }
 
-QStringList FileMetaDataWidget::Private::sortedKeys(const QVariantMap& data) const
+QStringList FileMetaDataWidgetPrivate::sortedKeys(const QVariantMap &data) const
 {
     // Create a map, where the translated label prefixed with the
     // sort priority acts as key. The data of each entry is the URI
@@ -262,7 +249,7 @@ QStringList FileMetaDataWidget::Private::sortedKeys(const QVariantMap& data) con
     return list;
 }
 
-void FileMetaDataWidget::Private::saveConfig()
+void FileMetaDataWidgetPrivate::saveConfig()
 {
     if (m_visibilityChanged.isEmpty()) {
         return;
@@ -280,18 +267,15 @@ void FileMetaDataWidget::Private::saveConfig()
     showGroup.sync();
 }
 
-FileMetaDataWidget::FileMetaDataWidget(QWidget* parent)
+FileMetaDataWidget::FileMetaDataWidget(QWidget *parent)
     : QWidget(parent)
-    , d(new Private(this))
+    , d(new FileMetaDataWidgetPrivate(this))
 {
 }
 
-FileMetaDataWidget::~FileMetaDataWidget()
-{
-    delete d;
-}
+FileMetaDataWidget::~FileMetaDataWidget() = default;
 
-void FileMetaDataWidget::setItems(const KFileItemList& items)
+void FileMetaDataWidget::setItems(const KFileItemList &items)
 {
     d->m_provider->setItems(items);
     d->m_widgetFactory->setItems(items);
@@ -314,7 +298,7 @@ bool FileMetaDataWidget::isReadOnly() const
 }
 void FileMetaDataWidget::setDateFormat(const DateFormats format)
 {
-     d->m_widgetFactory->setDateFormat(format);
+    d->m_widgetFactory->setDateFormat(format);
 }
 
 DateFormats FileMetaDataWidget::dateFormat() const
@@ -332,8 +316,8 @@ QSize FileMetaDataWidget::sizeHint() const
     int leftWidthMax = 0;
     int rightWidthMax = 0;
     int rightWidthAverage = 0;
-    for (const Private::Row& row : qAsConst(d->m_rows)) {
-        const QWidget* valueWidget = row.value;
+    for (const FileMetaDataWidgetPrivate::Row &row : qAsConst(d->m_rows)) {
+        const QWidget *valueWidget = row.value;
         const int rightWidth = valueWidget->sizeHint().width();
         rightWidthAverage += rightWidth;
         if (rightWidth > rightWidthMax) {
@@ -358,15 +342,13 @@ QSize FileMetaDataWidget::sizeHint() const
 
     // Based on the available width calculate the required height
     int height = d->m_gridLayout->margin() * 2 + d->m_gridLayout->spacing() * (d->m_rows.count() - 1);
-    for (const Private::Row& row : qAsConst(d->m_rows)) {
-        const QWidget* valueWidget = row.value;
-        const int rowHeight = qMax(row.label->heightForWidth(leftWidthMax),
-                                   valueWidget->heightForWidth(rightWidthMax));
+    for (const FileMetaDataWidgetPrivate::Row &row : qAsConst(d->m_rows)) {
+        const QWidget *valueWidget = row.value;
+        const int rowHeight = qMax(row.label->heightForWidth(leftWidthMax), valueWidget->heightForWidth(rightWidthMax));
         height += rowHeight;
     }
 
-    const int width = d->m_gridLayout->margin() * 2 + leftWidthMax +
-    d->m_gridLayout->spacing() + rightWidthMax;
+    const int width = d->m_gridLayout->margin() * 2 + leftWidthMax + d->m_gridLayout->spacing() + rightWidthMax;
 
     return QSize(width, height);
 }
