@@ -1,39 +1,23 @@
 /*
- * This file is part of the KDE Baloo Project
- * Copyright (C) 2017 Kai Uwe Broulik <kde@privat.broulik.de>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
- *
- */
+    SPDX-FileCopyrightText: 2017 Kai Uwe Broulik <kde@privat.broulik.de>
+
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 
 #include "baloofilepropertiesplugin.h"
 
 #include <QFrame>
-#include <QVBoxLayout>
 #include <QScrollArea>
+#include <QVBoxLayout>
 
-#include <KLocalizedString>
-#include <KPluginFactory>
 #include <KIO/JobUiDelegate>
 #include <KIO/OpenUrlJob>
+#include <KLocalizedString>
+#include <KPluginFactory>
 
 #include "filemetadatawidget.h"
 
-K_PLUGIN_FACTORY(BalooFilePropertiesPluginFactory, registerPlugin<BalooFilePropertiesPlugin>();)
+K_PLUGIN_CLASS_WITH_JSON(BalooFilePropertiesPlugin, "baloofilepropertiesplugin.json")
 
 BalooFilePropertiesPlugin::BalooFilePropertiesPlugin(QObject *parent, const QList<QVariant> &args)
     : KPropertiesDialogPlugin(qobject_cast<KPropertiesDialog *>(parent))
@@ -63,7 +47,9 @@ BalooFilePropertiesPlugin::BalooFilePropertiesPlugin(QObject *parent, const QLis
     metaDataArea->setWidgetResizable(true);
     metaDataArea->setFrameShape(QFrame::NoFrame);
 
-    properties->addPage(metaDataArea, i18nc("Tab page with file meta data", "&Details"));
+    connect(metaDataWidget, &Baloo::FileMetaDataWidget::metaDataRequestFinished, this, [this, metaDataArea, metaDataWidget] {
+        properties->addPage(metaDataArea, i18nc("Tab page with file meta data", "&Details"));
+    });
 }
 
 BalooFilePropertiesPlugin::~BalooFilePropertiesPlugin() = default;
